@@ -10,10 +10,10 @@ use warnings;
 
 use Carp;
 
-our $VERSION = '0.19_008';
+our $VERSION = '0.21_001';
 
 require Exporter;
-our @EXPORT;
+our @EXPORT_OK;
 our %EXPORT_TAGS;
 
 foreach my $impl (qw( Core XS Emul )) {
@@ -36,7 +36,7 @@ functions.
 =head1 SYNOPSIS
 
  use Socket qw( SOCK_STREAM );
- use Socket::GetAddrInfo qw( :newapi getaddrinfo getnameinfo );
+ use Socket::GetAddrInfo qw( getaddrinfo getnameinfo );
  use IO::Socket;
 
  my $sock;
@@ -87,10 +87,9 @@ real functions, and behave as close as is resonably possible to emulate using
 the legacy resolvers. See L<Socket::GetAddrInfo::Emul> for details on the
 limits of this emulation.
 
-As of C<Socket> version 1.93 (as shipped by Perl version 5.13.9, and hopefully
-will be in 5.14), core Perl already supports C<getaddrinfo>. On such a system,
-this module simply uses the functions provided by C<Socket>, and does not need
-to use its own compiled XS, or pure-perl legacy emulation.
+As of Perl version 5.14.0, Perl already supports C<getaddrinfo> in core. On
+such a system, this module simply uses the functions provided by C<Socket>,
+and does not need to use its own compiled XS, or pure-perl legacy emulation.
 
 =cut
 
@@ -120,9 +119,9 @@ Imports all of the above constants
 
 =cut
 
-$EXPORT_TAGS{AI}  = [ grep m/^AI_/,  @EXPORT ];
-$EXPORT_TAGS{NI}  = [ grep m/^NI_/,  @EXPORT ];
-$EXPORT_TAGS{EAI} = [ grep m/^EAI_/, @EXPORT ];
+$EXPORT_TAGS{AI}  = [ grep m/^AI_/,  @EXPORT_OK ];
+$EXPORT_TAGS{NI}  = [ grep m/^NI_/,  @EXPORT_OK ];
+$EXPORT_TAGS{EAI} = [ grep m/^EAI_/, @EXPORT_OK ];
 
 $EXPORT_TAGS{constants} = [ map @{$EXPORT_TAGS{$_}}, qw( AI NI EAI ) ];
 
@@ -200,7 +199,8 @@ Restrict to only generating addresses for this protocol
 Errors are indicated by the C<$err> value returned; which will be non-zero in
 numeric context, and contain a string error message as a string. The value can
 be compared against any of the C<EAI_*> constants to determine what the error
-is.
+is. Rather than explicitly checking, see also L<Socket::GetAddrInfo::Strict>
+which provides functions that throw exceptions on errors.
 
 If no error occurs, C<@res> will contain HASH references, each representing
 one address. It will contain the following five fields:
@@ -241,14 +241,17 @@ The optional C<$flags> parameter is a bitfield containing C<NI_*> constants.
 Errors are indicated by the C<$err> value returned; which will be non-zero in
 numeric context, and contain a string error message as a string. The value can
 be compared against any of the C<EAI_*> constants to determine what the error
-is.
+is. Rather than explicitly checking, see also L<Socket::GetAddrInfo::Strict>
+which provides functions that throw exceptions on errors.
 
 =cut
 
-# Keep perl happy; keep Britain tidy
-1;
+=head1 BUILDING WITHOUT XS CODE
 
-__END__
+In some environments it may be preferred not to build the XS implementation,
+leaving a choice only of the core or pure-perl emulation implementations.
+
+ $ PERL_SOCKET_GETADDRINFO_NO_BUILD_XS=1 perl Build.PL 
 
 =head1 BUGS
 
@@ -256,10 +259,10 @@ __END__
 
 =item *
 
-At the time of writing, there are no test reports from the C<MSWin32> platform
-either PASS or FAIL. I suspect the code will not currently work as it stands
-on that platform, but it should be fairly easy to fix, as C<Socket6> is known
-to work there. Patches welcomed. :)
+Appears to FAIL on older Darwin machines (e.g. C<osvers=8.11.1>). The failure
+mode occurs in F<t/02getnameinfo.t> and appears to relate to an endian bug;
+expecting to receive C<80> and instead receiving C<20480> (which is a 16-bit
+C<80> byte-swapped).
 
 =back
 
@@ -287,3 +290,7 @@ build fixes.
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
+
+=cut
+
+0x55AA;
