@@ -8,13 +8,13 @@ package Socket::GetAddrInfo::XS;
 use strict;
 use warnings;
 
-our $VERSION = '0.19_008';
+our $VERSION = '0.21_001';
 
 # Load the actual code into Socket::GetAddrInfo
 package # hide from indexer
   Socket::GetAddrInfo;
 
-our @EXPORT = qw(
+our @EXPORT_OK = qw(
    getaddrinfo
    getnameinfo
 );
@@ -24,5 +24,4 @@ die '$Socket::GetAddrInfo::NO_XS is set' if our $NO_XS;
 require XSLoader;
 XSLoader::load( __PACKAGE__, $Socket::GetAddrInfo::XS::VERSION );
 
-# Keep perl happy; keep Britain tidy
-1;
+0x55AA;
